import dayjs from 'dayjs'

export const descs = {
  SCHOOL: '截止到当日，【进行中】乐团的【合作单位】总数', // 合作单位
  MUSIC_GROUP_NUM: '截止到当日，【进行中】乐团总数', // 乐团数量
  MUSIC_GROUP_STUDENT: '截止到当日，【进行中】乐团【在读】学员总数，分部下去重', // 乐团学员
  OTHER_STUDENT: '截止到当日，学员有剩余VIP/网管未上课时的人数总数，分部下去重', // 其他学员
  ACTIVATION_RATE: '截止到当日，筹备中/进行中乐团在读学员和VIP/网管有课学员激活率', // 激活率
  HOMEWORK_CREATE_RATE: '本月截止到当日服务指标的作业布置率', // 作业布置率
  HOMEWORK_SUBMIT_RATE: '本月截止到当日已布置的作业学员提交率', // 作业提交率
  HOMEWORK_COMMENT_RATE: '本月截止到当日学员已提交的作业老师点评率', // 作业点评率
  SHOULD_INCOME_MONEY: '所有缴费项目应收金额总和', // 应收金额
  ANTICIPATED_INCOME_MONEY: '已缴费但实际还未产生费用金额总和', // 预收金额
  SHOULD_EXPEND_MONEY: '预计支出费用总和（暂无此数据）', // 预付金额
  ANTICIPATED_EXPEND_MONEY: '应付金额总和（暂无此数据）', // 应付金额
  REVENUE_MONEY: '营收金额总和', // 营收金额
  TEACHER_NUM: '截止到当日，【非冻结】的老师总数', // 老师总数
  FULL_TIME_NUM: '截止到当日，【非冻结】且工作类型为【全职】的老师总数', // 全职人数
  PART_TIME_NUM: '截止到当日，【非冻结】且工作类型为【兼职】的老师总数', // 兼职人数
  DIMISSION_NUM: '截止到当日，已冻结或将【离职时间】到筛选时间段内的老师总数', // 离职人数
  NEWLY_STUDENT_NUM: '本年度截止到当日，新增的乐团【在读】学员总数（去重）', // 新增学员
  QUIT_MUSIC_GROUP_STUDENT_NUM: '本年度截止到当日，乐团退团学员总数（去重）', // 退团学员
  STUDENT_CONVERSION: '乐团预报名学员中正式报名缴费的学员购买VIP/网管课的转化率（不包括退团学员）', // 学员转化
  MUSIC_GROUP_COURSE: '筛选时间段内，【已结束】乐团课程总数', // 乐团课
  VIP_GROUP_COURSE: '筛选时间段内，【已结束】VIP课程总数', // VIP课
  PRACTICE_GROUP_COURSE: '筛选时间段内，【已结束】网管课程总数', // 网管课
  FINANCE_PAY: '筛选时间段内支出金额总和', // 财务支出
  FINANCE_BALANCE_AMOUNT: '筛选时间段内余额消耗总和', // 余额收入
  FINANCE_AMOUNT: '筛选时间段内现金收入总和', // 现金收入
}

const dates = {
  start: dayjs().subtract(2, 'month').set('date', 1).format('YYYY-MM-DD'),
  end: dayjs().format('YYYY-MM-DD'),
}

export const errorType = {
  MUSIC_PATROL_ITEM: {
    name: '乐团巡查事项异常',
    isError: false,
    url: '/business/musicInspection',
    always: true,
    query: {
      tabrouter: 'teamSchedule',
      conclusionStatus: '1',
      ...dates,
    },
  },
  HIGH_CLASS_STUDENT_LESS_THAN_THREE: {
    name: '基础技能班学员数量异常',
    isError: true,
    url: '/business/teamCLassList',
    always: true,
    query: {
      lessThenThreeHighOnline: '1',
    },
  },
  STUDENT_NOT_PAYMENT: {
    name: '学员未缴费',
    isError: true,
    url: '/business/ArrearageStudents',
    always: true,
  },
  STUDENT_APPLY_FOR_QUIT_MUSIC_GROUP: {
    name: '学员退团申请',
    isError: true,
    url: '/business/WithdrawalApplication',
    always: true,
    query: {
      visitFlag: '0',
    },
  },
  WAIT_CREATE_PAYMENT_CALENDER: {
    name: '待创建缴费项目',
    isError: true,
    url: '/business/teamDetail',
    resultKey: 'search',
  },
  COURSE_TRUANT_STUDENT_NUM: {
    name: '学员考勤异常旷课',
    isError: true,
    url: '/operateManager/stuRecodeManager',
    always: true,
    query: {
      visitFlag: '0',
      status: 'TRUANT',
      ...dates,
    }
  },
  COURSE_LEAVE_STUDENT_NUM: {
    name: '学员请假',
    isError: true,
    url: '/operateManager/stuRecodeManager',
    always: true,
    query: {
      visitFlag: 0,
      status: 'LEAVE',
      ...dates,
    }
  },
  TEACHER_EXCEPTION_ATTENDANCE: {
    name: '课程考勤异常',
    isError: true,
    always: true,
    url: '/business/teamCourseList',
    query: {
      searchType: 'ERR_ATTENDANCE',
      ...dates,
    },
  },
  TEACHER_NOT_A_CLASS: {
    name: '课程异常',
    isError: true,
    always: true,
    url: '/business/teamCourseList',
    query: {
      searchType: 'NO_ATTENDANCE',
      ...dates,
    },
  },
  TEACHER_LEAVE: {
    name: '老师请假',
    isError: false,
    url: '/journal/journal',
    resultKey: 'search',
    query: {
      tabrouter: 'LEAVE'
    }
  },
  TEACHER_EXPECT_SALARY_BE_LOW: {
    name: '预计课酬较低',
    isError: false,
    url: '/operateManager/operationalList',
    always: true,
    query: {
      lowSalary: 1
    }
  },
  INSPECTION_ITEM: {
    name: '乐团巡查任务未计划',
    isError: true,
    always: true,
    url: '/main/main',
    resultKey: 'ids',
    query: {
      tabrouter: 'teamSchedule',
      searchType: 'INSPECTION_ITEM',
    },
  },
  INSPECTION_ITEM_PLAN: {
    name: '乐团巡查任务未提交',
    isError: true,
    url: '/business/musicInspection',
    always: true,
    query: {
      searchType: 'INSPECTION_ITEM_PLAN',
      ...dates
    },
  },
  STUDENT_VISIT: {
    name: '回访任务未完成',
    isError: true,
    url: '/main/main',
    always: true,
    query: {
      tabrouter: 'teamSchedule',
      searchType: 'STUDENT_VISIT',
      ...dates
    },
  },
}

export const matterTypes = {
  INSPECT: '下校巡查',
  VISIT: '学员回访',
}
